@@ -1,5 +1,5 @@
 from ..backend import KeyringBackend
-from .._compat import properties
+from ..compat import properties
 from ..errors import NoKeyringError
 
 
@@ -27,4 +27,4 @@ class Keyring(KeyringBackend):
         )
         raise NoKeyringError(msg)
 
-    set_password = delete_password = get_password  # type: ignore
+    set_password = delete_password = get_password
