@@ -42,7 +42,7 @@ class Keyring(backend.SchemeSelectable, KeyringBackend):
             ),
         )
 
-    @properties.NonDataProperty  # type: ignore
+    @properties.NonDataProperty
     def collection(self):
         return Secret.COLLECTION_DEFAULT
 
